'use strict';
var crypto = require('crypto');
var logger = require('./logger.js');

function normalize(value) {
  if (value === null) {
    return null;
  }

  if (Array.isArray(value)) {
    return value.map(function(element) {
      return normalize(element);
    });
  }

  if (typeof value === 'object') {
    return Object.keys(value).sort().map(function(key) {
      return [ key, normalize(value[key]) ];
    });
  }

  return value;
}

module.exports = function(object) {
  var normalized = normalize(object);
  var json = JSON.stringify(normalized);
  var algo = crypto.createHash('sha1');
  algo.update(json);
  var hash = algo.digest('base64').replace(/[^A-Za-z0-9]+/g, '');

  logger.debug('Hashed JSON object:');
  logger.debug('  Object: %s', JSON.stringify(object, null, 2));
  logger.debug('  Normalized: %s', JSON.stringify(normalized, null, 2));
  logger.debug('  Hash: %s', hash);

  return {
    hash: hash,
    json: json,
    normalized: normalized
  };
};
