'use strict';
var logger = require('./logger.js');

function queryTemplate(options) {
  if (!options || !options.body) throw new Error("Missing value for param 'body'");

  var body = options.body;
  var params = options.params || {};

  // Start with a full copy so we can replace params
  var query = JSON.parse(JSON.stringify(body));
  var objects = [query];

  while (objects.length > 0) {
    var object = objects.pop();
    Object.keys(object).forEach(function(key) {
      var value = object[key];

      if (typeof value === 'object') {
        objects.push(object[key]);
        return;
      }

      if (!/^[$]/.test(value)) {
        // Not a param
        return;
      }

      if (params.hasOwnProperty(value.substr(1))) {
        var newValue = params[value.substr(1)];
        object[key] = newValue;
      }
    });
  }

  logger.debug('Rendered query template:');
  logger.debug('  Params: %s', JSON.stringify(params, null, 2));
  logger.debug('  Template: %s', JSON.stringify(body, null, 2));
  logger.debug('  Query: %s', JSON.stringify(query, null, 2));

  return {
    query: query
  };
}

module.exports = queryTemplate;
