'use strict';
var url = require('url');
var Fixture = require('../../support/fixture.js');
var JsonHasher = require('../../../lib/json-hasher.js');

describe('todo', function() {
  var f = new Fixture();
  before(function() {
    return f.init()
    .then(function() {
      return f.createTodo();
    });
  });

  it('created project and tasks', function() {
    expect(f.project1.id).to.be.above(0);
    expect(f.task1.id).to.be.above(0);
    expect(f.task2.id).to.be.above(0);
  });

  it('responds to OPTIONS /todo/query', function() {
    return chai.request(f.todo.app)
    .options('/todo/query')
    .then(function(res) {
      expect(res).to.have.status(200);
      expect(res).to.have.header('allow', 'GET,OPTIONS,POST');
    });
  });

  var getTaskByNameHash;

  it('responds with correct hash for POST /todo/query', function() {
    var body = {
      modelName: 'Task',
      queryName: 'getTaskByName',
      queryTemplate: {
        where: { name: '$name' }
      }
    };

    getTaskByNameHash = new JsonHasher(body).hash;

    return chai.request(f.todo.app)
    .post('/todo/query')
    .send(body)
    .then(function(res) {
      expect(res).to.have.status(200);
      expect(res.body).to.have.property('hash', getTaskByNameHash);
    });
  });

  it('created a valid rest-query row in the database', function() {
    return f.schema.RestQuery.findAll({ where: { hash: getTaskByNameHash } })
    .then(function(queries) {
      expect(queries.length).to.equal(1);
    });
  });

  it('returns results for GET /todo/query/<hash> with params', function() {
    var queryUrl = url.format({
      pathname: '/todo/query/'+getTaskByNameHash,
      query: {
        name: f.task1.name
      }
    });

    return chai.request(f.todo.app)
    .get(queryUrl)
    .then(function(res) {
      expect(res).to.have.status(200);
      expect(res.body).to.have.property('modelName', 'Task');
    });
  });

  after(function() {
    return f.cleanup();
  });
});
