'use strict';
var express = require('express');
var logger = require('../../../lib/logger.js');
var RestDataAPI = require('../../../lib/index.js');

function Todo(schema) {
  this.app = express();

  this.restDataAPI = new RestDataAPI({
    base: '/todo/query',

    getQuery: function(options) {
      logger.debug('Finding query with hash %s', options.hash);
      return schema.RestQuery.findOne({ hash: options.hash })
      .then(function(restQuery) {
        return restQuery.get({ plain: true });
      });
    },

    runQuery: function(options) {
      return schema[options.modelName].findAll(options.query)
      .then(function(results) {
        return results.map(function(result) {
          return result.get({ plain: true });
        });
      });
    },

    upsertQuery: function(options) {
      return schema.RestQuery.findOrCreate({
        where: {
          hash: options.queryHash
        },
        defaults: {
          modelName: options.modelName,
          queryName: options.queryName,
          queryTemplate: options.queryTemplate
        }
      })
      .spread(function(restQuery) {
        return restQuery.get({ plain: true });
      });
    }
  });

  this.app.use(this.restDataAPI.middleware());
}

module.exports = Todo;
