'use strict';
var Sequelize = require('sequelize');
var requireDir = require('require-dir');
var logger = require('../../../../lib/logger.js');
var Models = requireDir('./');

var Schema = function(url) {
  this.url = url;
};

/**
 * Map model names to an instance of each model
 * For example, project.js becomes this.Project = new Project().model
 * @returns {void}
 */
Schema.prototype.init = function() {
  this.sequelize = new Sequelize(this.url, {
    sync: true,
    logging: logger.debug
  });

  Object.keys(Models).forEach(function(moduleName) {
    var Model = Models[moduleName](this.sequelize);
    this[Model.name] = this[moduleName] = Model;
  }.bind(this));

  Object.keys(Models).forEach(function(moduleName) {
    var Model = this[moduleName];
    if ('associate' in Model) {
      Model.associate(this);
    }
  }.bind(this));

  return this.sequelize.sync({ logging: logger.debug });
};

module.exports = Schema;
