'use strict';
var jsonHasher = require('../../lib/json-hasher.js');

describe('JsonHasher.normalize()', function() {
  it('empty object becomes empty array', function() {
    var result = jsonHasher({});
    expect(result.normalized).to.deep.equal([]);
  });

  it('empty array becomes empty array', function() {
    var result = jsonHasher([]);
    expect(result.normalized).to.deep.equal([]);
  });

  it('primitive values preserved', function() {
    var result = jsonHasher([
      1, 2, NaN, false, null, 'string', true, undefined
    ]);

    expect(result.normalized).to.deep.equal([
      1, 2, NaN, false, null, 'string', true, undefined
    ]);
  });

  it('turns objects into arrays', function() {
    var result = jsonHasher({
      array1: [4, 2, 7],
      object1: {
        array2: [false, true],
        object2: {
          foo: 'bar',
          zap: ['zing', 'abc']
        }
      }
    });

    expect(result.normalized).to.deep.equal([
      [ 'array1', [4, 2, 7] ],
      [ 'object1', [
        [ 'array2', [false, true] ],
        [ 'object2', [
          [ 'foo', 'bar' ],
          [ 'zap', ['zing', 'abc'] ]
        ]]
      ]]
    ]);
  });

  it('sorts object keys', function() {
    var result = jsonHasher({
      object1: {
        object2: {
          zap: ['zing', 'abc'],
          foo: 'bar'
        },
        array2: [false, true]
      },
      array1: [4, 2, 7]
    });

    expect(result.normalized).to.deep.equal([
      [ 'array1', [4, 2, 7] ],
      [ 'object1', [
        [ 'array2', [false, true] ],
        [ 'object2', [
          [ 'foo', 'bar' ],
          [ 'zap', ['zing', 'abc'] ]
        ]]
      ]]
    ]);
  });
});
