'use strict';
var queryTemplate = require('../../lib/query-template.js');

describe('queryTemplate(...).query', function() {
  it('is empty when template is empty', function() {
    var result = queryTemplate({ body: {}, params: {} });
    expect(result.query).to.deep.equal({});
  });

  it('is the template when there are no params', function() {
    var result = queryTemplate({ body: { name: '$name' } });
    expect(result.query).to.deep.equal({ name: '$name' });
  });

  it('has params rendered', function() {
    var result = queryTemplate({ body: { name: '$name' }, params: { name: 'Someone' } });
    expect(result.query).to.deep.equal({ name: 'Someone' });
  });

  it('renders with a complicated template and multiple params', function() {
    var result = queryTemplate({
      body: {
        name: '$name',
        email: 'test@example.com',
        address: {
          street: '$street',
          city: '$city',
          zip: 12345
        },
        tags: ['$tag1', '$tag2'],
        crazy: [
          { foo: '$bar' },
          { lol: ['$orly'] }
        ]
      },

      params: {
        name: 'Someone',
        street: '1234 Blah Road',
        city: 'Funky Town',
        tag1: 'bizarro',
        tag2: 'it',
        bar: 'grill',
        orly: 'yep'
      }
    });

    expect(result.query).to.deep.equal({
      name: 'Someone',
      email: 'test@example.com',
      address: {
        street: '1234 Blah Road',
        city: 'Funky Town',
        zip: 12345
      },
      tags: ['bizarro', 'it'],
      crazy: [
        { foo: 'grill' },
        { lol: ['yep'] }
      ]
    });
  });
});
